'use strict';

/* For ESLint: List any global identifiers used in this file below */
/* global STATS, log, determineUserLanguage */

// Log a message on GAB log server. The user's userid will be prepended to the
// message.
// If callback() is specified, call callback() after logging has completed
const sendMessageToLogServer = function (payload, callback) {
  $.ajax({
    jsonp: false,
    type: 'POST',
    url: 'https://log.getadblock.com/v2/record_log.php',
    data: JSON.stringify(payload),
    success() {
      if (typeof callback === 'function') {
        callback();
      }
    },

    error(e) {
      log('message server returned error: ', e.status);
    },
  });
};

// Log a message on GAB log server. The user's userid will be prepended to the
// message.
// If callback() is specified, call callback() after logging has completed
const recordMessageWithUserID = function (msg, queryType, callback, additionalParams) {
  if (!msg || !queryType) {
    return;
  }
  const data = {
    u: STATS.userId(),
    f: STATS.flavor,
    o: STATS.os,
    l: determineUserLanguage(),
    t: queryType,
  };
  if (typeof additionalParams === 'object') {
    for (const prop in additionalParams) {
      data[prop] = additionalParams[prop];
    }
  }
  const payload = { event: msg, payload: data };
  sendMessageToLogServer(payload, callback);
};

// Log a message on GAB log server.
// If callback() is specified, call callback() after logging has completed
const recordAnonymousMessage = function (msg, queryType, callback, additionalParams) {
  if (!msg || !queryType) {
    return;
  }

  const data = {
    f: STATS.flavor,
    o: STATS.os,
    l: determineUserLanguage(),
    t: queryType,
  };
  if (typeof additionalParams === 'object') {
    for (const prop in additionalParams) {
      data[prop] = additionalParams[prop];
    }
  }
  const payload = { event: msg, payload: data };
  sendMessageToLogServer(payload, callback);
};

const recordErrorMessage = function (msg, callback, additionalParams) {
  recordMessageWithUserID(msg, 'error', callback, additionalParams);
};

// Log an 'status' related message on GAB log server.
const recordStatusMessage = function (msg, callback, additionalParams) {
  recordMessageWithUserID(msg, 'stats', callback, additionalParams);
};

// Log a 'general' message on GAB log server.
const recordGeneralMessage = function (msg, callback, additionalParams) {
  recordMessageWithUserID(msg, 'general', callback, additionalParams);
};

Object.assign(window, {
  recordErrorMessage,
  recordStatusMessage,
  recordGeneralMessage,
  recordMessageWithUserID,
  recordAnonymousMessage,
});
